Index: main/xmldoc.c
===================================================================
--- main/xmldoc.c	(revision 206378)
+++ main/xmldoc.c	(working copy)
@@ -61,7 +61,9 @@
 
 static char *xmldoc_get_syntax_cmd(struct ast_xml_node *fixnode, const char *name, int printname);
 static int xmldoc_parse_enumlist(struct ast_xml_node *fixnode, const char *tabs, struct ast_str **buffer);
+static int xml_pathmatch(glob_t *globbuf);
 
+
 /*!
  * \brief Container of documentation trees
  *
@@ -1815,6 +1817,51 @@
 	return xmldoc_build_field(type, name, "description", 0);
 }
 
+/*! \internal
+ *  \brief Get every *-LANG.xml file inside $(ASTDATADIR)/documentation.
+ *  \param globbuf patterns that matched.
+ *  \retval 0 on success.
+ *  \retval 1 on error.
+ */
+static int xml_pathmatch(glob_t *globbuf)
+{
+	char *xmlpattern;
+	int globret;
+	int len;
+
+	len = strlen(ast_config_AST_DATA_DIR)+6+36;
+	xmlpattern = alloca(len);
+
+	snprintf(xmlpattern, len,"%s/documentation/*-%s.xml", 
+			ast_config_AST_DATA_DIR, documentation_language);
+	globret = glob(xmlpattern, MY_GLOB_FLAGS, NULL, globbuf);
+	snprintf(xmlpattern, len, "%s/documentation/*-%.2s_??.xml", 
+			ast_config_AST_DATA_DIR, documentation_language);
+	globret = glob(xmlpattern, MY_GLOB_FLAGS | GLOB_APPEND, NULL, globbuf);
+	snprintf(xmlpattern, len, "%s/documentation/*-%s.xml", 
+			ast_config_AST_DATA_DIR, default_documentation_language);
+	globret = glob(xmlpattern, MY_GLOB_FLAGS | GLOB_APPEND, NULL, globbuf);
+	snprintf(xmlpattern, len, "%s/documentation/thirdparty/*-%s.xml", 
+			ast_config_AST_DATA_DIR, documentation_language);
+	globret = glob(xmlpattern, MY_GLOB_FLAGS | GLOB_APPEND, NULL, globbuf);
+	snprintf(xmlpattern, len, "%s/documentation/thirdparty/*-%.2s_??.xml", 
+			ast_config_AST_DATA_DIR, documentation_language);
+	globret = glob(xmlpattern, MY_GLOB_FLAGS | GLOB_APPEND, NULL, globbuf);
+	snprintf(xmlpattern, len, "%s/documentation/thirdparty/*-%s.xml", 
+			ast_config_AST_DATA_DIR, default_documentation_language);
+	globret = glob(xmlpattern, MY_GLOB_FLAGS | GLOB_APPEND, NULL, globbuf);
+
+	if (globret == GLOB_NOSPACE) {
+		ast_log(LOG_WARNING, "Glob failed: Not enough memory\n");
+		return 1;
+	} else if (globret  == GLOB_ABORTED) {
+		ast_log(LOG_WARNING, "Glob failed: Read error\n");
+		return 1;
+	}
+	
+	return 0;
+}
+
 /*! \brief Close and unload XML documentation. */
 static void xmldoc_unload_documentation(void)
 {
@@ -1835,11 +1882,10 @@
 	struct ast_xml_node *root_node;
 	struct ast_xml_doc *tmpdoc;
 	struct documentation_tree *doc_tree;
-	char *xmlpattern;
 	struct ast_config *cfg = NULL;
 	struct ast_variable *var = NULL;
 	struct ast_flags cnfflags = { 0 };
-	int globret, i, dup, duplicate;
+	int i, dup, duplicate;
 	glob_t globbuf;
 
 	/* setup default XML documentation language */
@@ -1862,21 +1908,12 @@
 	/* register function to be run when asterisk finish. */
 	ast_register_atexit(xmldoc_unload_documentation);
 
-	/* Get every *-LANG.xml file inside $(ASTDATADIR)/documentation */
-	ast_asprintf(&xmlpattern, "%s/documentation{/thirdparty/,/}*-{%s,%.2s_??,%s}.xml", ast_config_AST_DATA_DIR,
-			documentation_language, documentation_language, default_documentation_language);
 	globbuf.gl_offs = 0;    /* initialize it to silence gcc */
-	globret = glob(xmlpattern, MY_GLOB_FLAGS, NULL, &globbuf);
-	if (globret == GLOB_NOSPACE) {
-		ast_log(LOG_WARNING, "Glob Expansion of pattern '%s' failed: Not enough memory\n", xmlpattern);
-		ast_free(xmlpattern);
+
+	/* If there is a problem with searching for XML doc return early */
+	if(xml_pathmatch(&globbuf) == 1) {
 		return 1;
-	} else if (globret  == GLOB_ABORTED) {
-		ast_log(LOG_WARNING, "Glob Expansion of pattern '%s' failed: Read error\n", xmlpattern);
-		ast_free(xmlpattern);
-		return 1;
 	}
-	ast_free(xmlpattern);
 
 	AST_RWLIST_WRLOCK(&xmldoc_tree);
 	/* loop over expanded files */
